
# My Awesome Library

This is a Python library that provides basic math utility functions.

## Installation

You can install this library using `pip`:

```bash
pip install ragshu
```

## Usage

```python
from ragshu import add

result = add(1, 2)
print(result)  # Output: 3
```
